#pragma once
#include "FFGL.h"
#include "ParamBase.h"

namespace ffgl
{
class ParamFloat : public ParamBase
{
public:
	enum class Grouping : FFUInt32
	{
		NONE = 1,
		VEC2 = 2,
		VEC3 = 3,
		VEC4 = 4
	};

protected:
	float value = 0.0f;
	float defaultValue = 0.0f;
	Grouping grouping = Grouping::NONE;

public:

	ParamFloat( const std::string& name, float defaultValue = 0.0f, Grouping grouping = Grouping::NONE );
	ParamFloat( const std::string& name, const std::string& uniformName, float defaultValue = 0.0f, Grouping grouping = Grouping::NONE );
	ParamFloat( const std::string& name, ParameterType type, float defaultValue = 0.0f, Grouping grouping = Grouping::NONE );
	ParamFloat( const std::string& name, ParameterType type, const std::string& uniformName, float defaultValue = 0.0f, Grouping grouping = Grouping::NONE );

	~ParamFloat();

	void Reset() override;
	const std::string& GetDisplay() const override;
	FFMixed GetMixedDefault() const override;
	FFMixed GetMixedValue() const override;
	FFResult SetMixedValue( FFMixed mixed ) override;

	virtual float GetFloatDefault() const;
	virtual float GetFloatValue() const;
	virtual void SetFloatValue( float floatValue );

	Grouping GetGrouping() const
	{
		return grouping;
	}

	Grouping SetGrouping(Grouping grouping)
	{
		this->grouping = grouping;
	}
};

}//End namespace ffgl
